<?php
namespace wcf\system\event\listener;
use wcf\system\event\IEventListener;
use wcf\system\WCF;

/**
 * Handles additional conditions in user search / user bulk processing.
 *
 * @author	Sascha Greuel <sascha@softcreatr.de>
 * @copyright	2013-2014 Sascha Greuel
 * @license	Creative Commons Attribution-NoDerivatives <http://creativecommons.org/licenses/by-nd/4.0/legalcode>
 * @package	be.bastelstu.sascha.termsofuse
 * @subpackage	system.event.listener
 * @category	Community Framework
 */
class UserSearchFormTermsOfUseListener implements IEventListener {
	/**
	 * form object
	 * @var	\wcf\acp\form\AbstractForm
	 */
	protected $eventObj = null;

	/**
	 * terms of use accepted
	 * @var	boolean
	 */
	public $termsAccepted = false;

	/**
	 * terms of use not accepted
	 * @var	boolean
	 */
	public $termsNotAccepted = false;

	/**
	 * @see	\wcf\system\event\IEventListener::execute()
	 */
	public function execute($eventObj, $className, $eventName) {
		if (!MODULE_USER_TERMS_OF_USE) {
			return;
		}

		$this->eventObj = $eventObj;

		$this->$eventName();
	}

	/**
	 * Handles the readFormParameters event.
	 */
	protected function readFormParameters() {
		if (!empty($_POST['termsAccepted'])) $this->termsAccepted = true;
		if (!empty($_POST['termsNotAccepted'])) $this->termsNotAccepted = true;
	}

	/**
	 * Handles the assignVariables event.
	 */
	protected function assignVariables() {
		WCF::getTPL()->assign(array(
			'termsAccepted' => $this->termsNotAccepted,
			'termsNotAccepted' => $this->termsNotAccepted
		));
	}

	/**
	 * Handles the buildConditions event.
	 */
	protected function buildConditions() {
		if ($this->termsAccepted) {
			$this->eventObj->conditions->add('user_table.disclaimerAccepted = ?', array(1));
		}

		if ($this->termsNotAccepted) {
			$this->eventObj->conditions->add('user_table.disclaimerAccepted <> ?', array(1));
		}
	}
}
